'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getTransformedDestinationResponse;

var _npmlog = require('npmlog');

var _npmlog2 = _interopRequireDefault(_npmlog);

var _collection = require('lodash/collection');

var _getOutdatedDestinationContent = require('contentful-batch-libs/get/get-outdated-destination-content');

var _getOutdatedDestinationContent2 = _interopRequireDefault(_getOutdatedDestinationContent);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Gets the response from the destination space with the content that needs
 * to be updated. If it's the initial sync, and content exists, we abort
 * and tell the user why.
 */
function getTransformedDestinationResponse(_ref) {
  var managementClient = _ref.managementClient;
  var spaceId = _ref.spaceId;
  var sourceResponse = _ref.sourceResponse;
  var skipContentModel = _ref.skipContentModel;

  return (0, _getOutdatedDestinationContent2.default)({
    managementClient: managementClient,
    spaceId: spaceId,
    entryIds: (0, _collection.map)(sourceResponse.entries, 'sys.id'),
    assetIds: (0, _collection.map)(sourceResponse.assets, 'sys.id')
  }).then(function (destinationResponse) {
    if (skipContentModel) {
      destinationResponse.contentTypes = [];
      destinationResponse.locales = [];
    }

    if (sourceResponse.isInitialSync && (destinationResponse.contentTypes.length > 0 || destinationResponse.assets.length > 0)) {
      _npmlog2.default.error('\nYour destination space already has some content.\n\nIf you have a token file, please place it on the same directory which you are currently in.\n\nOtherwise, please run this tool on an empty space.\n\nIf you\'d like more information, please consult the README at:\nhttps://github.com/contentful/contentful-space-sync\n');
      process.exit(1);
    }
    return destinationResponse;
  });
}